@@ -1,7 +1,7 @@
-use anyhow::Result;
 use std::iter::repeat_with;
 use std::sync::Arc;
 
+use futuresdr::anyhow::Result;
 use futuresdr::blocks::VectorSink;
 use futuresdr::blocks::VectorSinkBuilder;
 use futuresdr::blocks::VectorSourceBuilder;
