@@ -1,3 +1,37 @@
+//! ## Generic blocks
+//! | Block | Usage | WebAssembly? |
+//! |---|---|---|
+//! | [Apply] | Apply a function to each sample | ✅ |
+//! | [Combine] | Apply a function to combine two streams into one | ✅ |
+//! | [Filter] | Apply a function to filter samples | ✅ |
+//!
+//! ## DSP blocks
+//! | Block | Usage | WebAssembly? |
+//! |---|---|---|
+//! | [fir](FirBuilder) | Generic FIR filter | ✅ |
+//! | [fft](FftBuilder) | Computes FFT | ✅ |
+//!
+//! ## Limiting blocks
+//! | Block| Usage | WebAssembly? |
+//! |---|---|---|
+//! | [Throttle] | Limits graph sample rate | ❌ |
+//! | [Head] | Stops graph after specified number of samples | ✅ |
+//!
+//! ## Source/sink blocks
+//! | Block | Usage | WebAssembly? |
+//! |---|---|---|
+//! | [FileSource] | Reads samples from a file | ❌ |
+//! | [SoapySource](SoapySourceBuilder) | Read samples from a soapy device | ❌ |
+//! | [Source] | Repeatedly apply a function to generate samples | ✅ |
+//! | [NullSource] | Generates a stream of zeros | ✅ |
+//! | [FileSink] | Writes samples to a file | ❌ |
+//! | [NullSink] | Drops samples | ✅ |
+//!
+//! ## Message blocks
+//! | Block | Usage | WebAssembly? |
+//! |---|---|---|
+//! | [MessageSource](MessageSourceBuilder) | Repeats a fixed message on an interval | ❌ |
+
 mod apply;
 pub use apply::Apply;
 
@@ -42,6 +76,9 @@ pub use finite_source::FiniteSource;
 mod head;
 pub use head::Head;
 
+mod iir;
+pub use iir::{Iir, IirBuilder};
+
 #[cfg(feature = "lttng")]
 pub mod lttng;
 
